@@ -4,7 +4,7 @@
 # looks like
 #
 # [[local|localrc]]
-# enable_plugin panko git://git.openstack.org/openstack/panko
+# enable_plugin panko https://opendev.org/openstack/panko
 #
 # Several variables set in the localrc section adjust common behaviors
 # of Panko (see within for additional settings):
@@ -101,8 +101,8 @@ function _panko_prepare_storage_backend {
     fi
 
     if [ "$PANKO_BACKEND" = 'es' ] ; then
-        ${TOP_DIR}/pkg/elasticsearch.sh download
-        ${TOP_DIR}/pkg/elasticsearch.sh install
+         $PANKO_DIR/devstack/lib/elasticsearch.sh download
+         $PANKO_DIR/devstack/lib/elasticsearch.sh install
     fi
 }
 
