@@ -21,6 +21,7 @@ from oslo_db import exception as dbexc
 from oslo_db.sqlalchemy import session as db_session
 from oslo_db.sqlalchemy import utils as oslo_sql_utils
 from oslo_log import log
+from oslo_utils import importutils
 from oslo_utils import timeutils
 import sqlalchemy as sa
 from sqlalchemy.engine import url as sqlalchemy_url
@@ -34,6 +35,8 @@ from panko import utils
 
 LOG = log.getLogger(__name__)
 
+osprofiler_sqlalchemy = importutils.try_import('osprofiler.sqlalchemy')
+
 
 AVAILABLE_CAPABILITIES = {
     'events': {'query': {'simple': True}},
@@ -136,6 +139,10 @@ class Connection(base.Connection):
             options.pop(opt.name, None)
         self._engine_facade = db_session.EngineFacade(self.dress_url(url),
                                                       **options)
+        if osprofiler_sqlalchemy:
+            osprofiler_sqlalchemy.add_tracing(sa,
+                                              self._engine_facade.get_engine(),
+                                              'db')
 
     @staticmethod
     def dress_url(url):
@@ -206,7 +213,7 @@ class Connection(base.Connection):
                             session.execute(model.__table__.insert(),
                                             trait_map[dtype])
             except dbexc.DBDuplicateEntry as e:
-                LOG.info("Duplicate event detected, skipping it: %s", e)
+                LOG.debug("Duplicate event detected, skipping it: %s", e)
             except KeyError as e:
                 LOG.exception('Failed to record event: %s', e)
             except Exception as e:
